@@ -59,7 +59,7 @@ def inference():
         result['error_summary'] = ''
         name, ext = os.path.splitext(file.filename)
         result['metadata']['name'] = slugify(name)
-    response.data = json.dumps(result)
+    response.data = json.dumps(result, default=str)
     return response
 
 
@@ -223,21 +223,6 @@ def save_package():
     return response
 
 
-# def validate_package():
-#     context = {
-#         'model': model,
-#         'session': model.Session,
-#         'user': toolkit.c.user,
-#         'auth_user_obj': toolkit.c.userobj,
-#         'api_version': 3,
-#         'for_edit': True,
-#     }
-#     try:
-#         toolkit.check_access('package_create', context)
-#     except toolkit.NotAuthorized:
-#         toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
-
-
 def publish_package():
     context = {
         'model': model,
@@ -269,16 +254,19 @@ def publish_package():
         data_response['has_error'] = True
     else:
         def _validate():
-            admin = model.Session.query(model.User).filter(model.User.sysadmin==True).first()
+            token = settings.get('token')
             session = requests.Session()
-            session.headers['Authorization'] = admin.apikey
+            if token:
+                session.headers['Authorization'] = token
             site_url = config.get('ckan.site_url')
             if site_url.endswith('/'):
                 url = f"{site_url}datapackage-creator/show-datapackage-json/{data['id']}"
             else:
                 url = f"{site_url}/datapackage-creator/show-datapackage-json/{data['id']}"
             with frictionless.system.use_http_session(session) as ctx:
-                validation = frictionless.validate(url)
+                datapackage_json = requests.get(url).json()
+                package = frictionless.Package(datapackage_json)
+                validation = package.validate(skip_errors=["byte-count-error"])
             datapackage = model.Session.query(Datapackage).filter(
                 Datapackage.package_id==package_data['id']
             ).order_by(Datapackage.created.desc()).first()
