@@ -23,6 +23,7 @@ def ckan_resource_to_frictionless(resource):
             fields = extras['fields']
         except:
             pass
+        uniques = []
         for field in fields:
             field_dict = {
                 'name': field.get('name', ''),
@@ -31,10 +32,14 @@ def ckan_resource_to_frictionless(resource):
                 'format': field.get('format'),
                 'description': field.get('description', ''),
                 'type': field.get('type', ''),
+                'constraints': {
+                    'unique': field.get('unique', False),
+                    'required': field.get('required', False),
+                }
             }
             primary_key = field.get('primary_key')
             if primary_key:
-                frictionless_resource['schema']['primary_key'] = field['name']
+                frictionless_resource['schema']['primaryKey'] = field['name']
             foreign_key = field.get('foreign_key')
             if foreign_key:
                 try:
@@ -51,6 +56,8 @@ def ckan_resource_to_frictionless(resource):
                             }
                         }
                     )
+            if uniques:
+                frictionless_resource['schema']['uniqueKeys'] = uniques
             frictionless_resource['schema']['fields'].append(field_dict)
         if foreign_keys:
             frictionless_resource['foreignKeys'] = []
@@ -77,8 +84,6 @@ def ckan_to_frictionless(package):
                     contributor_item['path'] = contributor['url']
                 frictionless_package['contributors'].append(contributor_item)
             frictionless_package['frequency'] = extras['frequency']
-            for extra in package['extras']:
-                frictionless_package[extra['key']] = extra['value']
         resources = []
         for resource in package['resources']:
             frictionless_resource = ckan_resource_to_frictionless(resource)
